@@ -108,6 +108,7 @@ typedef struct input_translation_s {
 	uint32_t    byte_offset;
 	uint32_t	ICMP_offset;
 	uint32_t	sampler_offset;
+	uint32_t	sampler_size;
 	uint32_t	router_ip_offset;
 	uint32_t	engine_offset;
 	uint32_t	extension_map_changed;
@@ -197,7 +198,7 @@ static struct element_info_s {
 	{ 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, { 0, 0, 0}, 
 	
 	// 48 - 54   not implemented
-	{ 1, 1, 0}, 	// 48 - NF9_FLOW_SAMPLER_ID
+	{ 1, 2, 0}, 	// 48 - NF9_FLOW_SAMPLER_ID
 	{ 1, 1, 0}, 	// 49 - FLOW_SAMPLER_MODE
 	{ 4, 4, 0}, 	// 50 - NF9_FLOW_SAMPLER_RANDOM_INTERVAL
 
@@ -546,6 +547,7 @@ size_t				size_required;
 	table->flags		= 0;
 	table->ICMP_offset	= 0;
 	table->sampler_offset 	= 0;
+	table->sampler_size 	= 0;
 	table->engine_offset 	= 0;
 	table->router_ip_offset = 0;
 
@@ -626,13 +628,11 @@ size_t				size_required;
 		if ( map_table[i] == 0 )
 			continue;
 
-		extension_map->size += sizeof(uint16_t);
-		extension_map->extension_size += extension_descriptor[i].size;
 		switch(i) {
 			case EX_IO_SNMP_2:
 			case EX_IO_SNMP_4:
 				// 2 byte length
-				if ( input_template[NF9_IN_BYTES].length <= 2 || input_template[NF9_OUTPUT_SNMP].length <= 2) {
+				if ( input_template[NF9_INPUT_SNMP].length <= 2 || input_template[NF9_OUTPUT_SNMP].length <= 2) {
 					FillElement( table, NF9_INPUT_SNMP, &offset);
 					FillElement( table, NF9_OUTPUT_SNMP, &offset);
 					map_index = EX_IO_SNMP_2;
@@ -703,7 +703,7 @@ size_t				size_required;
 				break;
 			case EX_OUT_BYTES_4:
 			case EX_OUT_BYTES_8:
-				if ( input_template[NF9_OUT_PKTS].length <= 4 ) {
+				if ( input_template[NF9_OUT_BYTES].length <= 4 ) {
 					FillElement( table, NF9_OUT_BYTES, &offset);
 					map_index = EX_OUT_BYTES_4;
 				} else {
@@ -771,6 +771,8 @@ size_t				size_required;
 				// unused fill element for 32bit alignment
 				break;
 		}
+		extension_map->size += sizeof(uint16_t);
+		extension_map->extension_size += extension_descriptor[map_index].size;
 
 		// found extension in map_index must be the same as in map - otherwise map is dirty
 		if ( extension_map->ex_id[next_extension] != map_index ) {
@@ -806,11 +808,17 @@ size_t				size_required;
 	if ( input_template[NF9_FLOW_SAMPLER_ID].offset != 0 ) {
 		if ( input_template[NF9_FLOW_SAMPLER_ID].length == 1 ) {
 			table->sampler_offset = input_template[NF9_FLOW_SAMPLER_ID].offset;
-			dbg_printf("Sampling ID included at offset %u\n", table->sampler_offset);
-		} else {
+			table->sampler_size = 1;
+			dbg_printf("1 byte Sampling ID included at offset %u\n", table->sampler_offset);
+		} else if ( input_template[NF9_FLOW_SAMPLER_ID].length == 2 ) {
+			table->sampler_offset = input_template[NF9_FLOW_SAMPLER_ID].offset;
+			table->sampler_size = 2;
+			dbg_printf("2 byte Sampling ID included at offset %u\n", table->sampler_offset);
+		}  else {
 			syslog(LOG_ERR, "Process_v9: Unexpected SAMPLER ID field length: %d", 
 				input_template[NF9_FLOW_SAMPLER_ID].length);
-			dbg_printf("Sampling ID included\n");
+			dbg_printf("Unexpected SAMPLER ID field length: %d", 
+				input_template[NF9_FLOW_SAMPLER_ID].length);
 		}
 	} else {
 		dbg_printf("No Sampling ID found\n");
@@ -895,11 +903,11 @@ int			i;
 			// do we store this extension? enabled != 0
 			// more than 1 v9 tag may map to an extension - so count this extension once only
 			if ( ext_id && extension_descriptor[ext_id].enabled ) {
+				dbg_printf("Type: %u, Length %u => Extension: %u\n", field_type, field_length, ext_id);
 				if ( map_table[ext_id] == 0 ) {
 					map_table[ext_id] = 1;
 					num_extensions++;
 				}
-				dbg_printf("Type: %u, Length %u => Extension: %u\n", field_type, field_length, ext_id);
 			} else {
 				dbg_printf("Type: %u, Length %u\n", field_type, field_length);
 			}
@@ -947,7 +955,7 @@ int			i;
 static inline void Process_v9_option_templates(exporter_domain_t *exporter, void *option_template_flowset, FlowSource_t *fs) {
 void		*option_template, *p;
 uint32_t	size_left, nr_scopes, nr_options, i;
-uint16_t	id, scope_length, option_length, offset;
+uint16_t	id, scope_length, option_length, offset, sampler_id_length;
 uint16_t	offset_sampler_id, offset_sampler_mode, offset_sampler_interval, found_sampler;
 uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sampling;
 
@@ -982,13 +990,14 @@ uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sa
 	dbg_printf("\n[%u] Option Template ID: %u\n", exporter->exporter_id, id);
 	dbg_printf("Scope length: %u Option length: %u\n", scope_length, option_length);
 
-	offset_sampler_id 				= 0;
-	offset_sampler_mode 			= 0;
-	offset_sampler_interval 		= 0;
+	sampler_id_length			 = 0;
+	offset_sampler_id 			 = 0;
+	offset_sampler_mode			 = 0;
+	offset_sampler_interval 	 = 0;
 	offset_std_sampler_interval  = 0;
 	offset_std_sampler_algorithm = 0;
-	found_sampler					= 0;
-	found_std_sampling			= 0;
+	found_sampler				 = 0;
+	found_std_sampling			 = 0;
 	offset = 0;
 
 	p = option_template + 6;	// start of length/type data
@@ -1007,6 +1016,11 @@ uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sa
 		uint16_t type 	= Get_val16(p); p = p + 2;
 		uint16_t length = Get_val16(p); p = p + 2;
 		dbg_printf("Option field Type: %u, length %u\n", type, length);
+		if ( element_info[type].min && CheckElementLength(type, length) == 0 ) {
+			syslog(LOG_ERR,"Process_v9: Option field Type: %u, length %u not supported\n", type, length);
+			dbg_printf("Process_v9: Option field Type: %u, length %u not supported\n", type, length);
+			continue;
+		}
 		switch (type) {
 			// general sampling
 			case NF9_SAMPLING_INTERVAL:
@@ -1021,6 +1035,7 @@ uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sa
 			// individual samplers
 			case NF9_FLOW_SAMPLER_ID:
 				offset_sampler_id = offset;
+				sampler_id_length = length;
 				found_sampler++;
 				break;
 			case FLOW_SAMPLER_MODE:
@@ -1037,7 +1052,7 @@ uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sa
 
 	if ( found_sampler == 3 ) { // need all three tags
 		dbg_printf("[%u] Sampling information found\n", exporter->exporter_id);
-		InsertSamplerOffset(fs, id, offset_sampler_id, offset_sampler_mode, offset_sampler_interval);
+		InsertSamplerOffset(fs, id, offset_sampler_id, sampler_id_length, offset_sampler_mode, offset_sampler_interval);
 	} else if ( found_std_sampling == 2 ) { // need all two tags
 		dbg_printf("[%u] Std sampling information found\n", exporter->exporter_id);
 		InsertStdSamplerOffset(fs, id, offset_std_sampler_interval, offset_std_sampler_algorithm);
@@ -1045,6 +1060,7 @@ uint16_t	offset_std_sampler_interval, offset_std_sampler_algorithm, found_std_sa
 		dbg_printf("[%u] No Sampling information found\n", exporter->exporter_id);
 	}
 	dbg_printf("\n");
+	processed_records++;
 
 } // End of Process_v9_option_templates
 
@@ -1065,7 +1081,12 @@ char				*string;
 
 	// Check if sampling is announced
 	if ( table->sampler_offset && fs->sampler  ) {
-		uint8_t sampler_id = in[table->sampler_offset];
+		uint32_t sampler_id;
+		if ( table->sampler_size == 2 ) {
+			sampler_id = Get_val16((void *)&in[table->sampler_offset]);
+		} else {
+			sampler_id = in[table->sampler_offset];
+		}
 		if ( fs->sampler[sampler_id] ) {
 			sampling_rate = fs->sampler[sampler_id]->interval;
 			dbg_printf("[%u] Sampling ID %u available\n", exporter->exporter_id, sampler_id);
@@ -1107,7 +1128,7 @@ char				*string;
 		}
 
 		// check for enough space in output buffer
-		if ( !CheckBufferSpace(&(fs->nffile), table->output_record_size) ) {
+		if ( !CheckBufferSpace(fs->nffile, table->output_record_size) ) {
 			// this should really never occur, because the buffer gets flushed ealier
 			syslog(LOG_ERR,"Process_v9: output buffer size error. Abort v9 record processing");
 			dbg_printf("Process_v9: output buffer size error. Abort v9 record processing");
@@ -1116,7 +1137,7 @@ char				*string;
 		processed_records++;
 
 		// map file record to output buffer
-		data_record	= (common_record_t *)fs->nffile.writeto;
+		data_record	= (common_record_t *)fs->nffile->writeto;
 		// map output buffer as a byte array
 		out 	  = (uint8_t *)data_record;
 
@@ -1363,29 +1384,29 @@ char				*string;
 		if ( verbose ) {
 			master_record_t master_record;
 			ExpandRecord_v2((common_record_t *)data_record, &(table->extension_info), &master_record);
-		 	format_file_block_record(&master_record, &string, 0, 0);
+		 	format_file_block_record(&master_record, &string, 0);
 			printf("%s\n", string);
 		}
 
-		fs->nffile.block_header->size  += data_record->size;
-		fs->nffile.block_header->NumRecords++;
-		fs->nffile.writeto	= (common_record_t *)((pointer_addr_t)data_record + data_record->size);
+		fs->nffile->block_header->size  += data_record->size;
+		fs->nffile->block_header->NumRecords++;
+		fs->nffile->writeto	= (common_record_t *)((pointer_addr_t)data_record + data_record->size);
 
 		// advance input
 		size_left 		   -= table->input_record_size;
 		in  	  		   += table->input_record_size;
 
 		// buffer size sanity check
-		if ( fs->nffile.block_header->size  > BUFFSIZE ) {
+		if ( fs->nffile->block_header->size  > BUFFSIZE ) {
 			// should never happen
 			syslog(LOG_ERR,"### Software error ###: %s line %d", __FILE__, __LINE__);
 			syslog(LOG_ERR,"Process v9: Output buffer overflow! Flush buffer and skip records.");
-			syslog(LOG_ERR,"Buffer size: %u > %u", fs->nffile.block_header->size, BUFFSIZE);
+			syslog(LOG_ERR,"Buffer size: %u > %u", fs->nffile->block_header->size, BUFFSIZE);
 
 			// reset buffer
-			fs->nffile.block_header->size 		= 0;
-			fs->nffile.block_header->NumRecords = 0;
-			fs->nffile.writeto = (void *)((pointer_addr_t)fs->nffile.block_header + sizeof(data_block_header_t) );
+			fs->nffile->block_header->size 		= 0;
+			fs->nffile->block_header->NumRecords = 0;
+			fs->nffile->writeto = (void *)((pointer_addr_t)fs->nffile->block_header + sizeof(data_block_header_t) );
 			return;
 		}
 
@@ -1419,7 +1440,11 @@ uint8_t		*in;
 
 	if ( TestFlag(offset_table->flags, HAS_SAMPLER_DATA) ) {
 		sampler.table_id = id;
-		sampler_id 	 	 = in[offset_table->offset_id];
+		if (offset_table->sampler_id_length == 2) {
+			sampler_id 	 	 = Get_val16((void *)&in[offset_table->offset_id]);
+		} else {
+			sampler_id 	 	 = in[offset_table->offset_id];
+		}
 		sampler.mode 	 = in[offset_table->offset_mode];
 		sampler.interval = Get_val32((void *)&in[offset_table->offset_interval]); 
 	
@@ -1445,7 +1470,8 @@ uint8_t		*in;
 		dbg_printf("Set std sampler: algorithm: %u, interval: %u\n", 
 				fs->std_sampling.mode, fs->std_sampling.interval);
 	}
-
+	processed_records++;
+			
 } // End of Process_v9_option_data
 
 void Process_v9(void *in_buff, ssize_t in_buff_cnt, FlowSource_t *fs) {
@@ -1461,6 +1487,7 @@ static int pkg_num = 0;
 	pkg_num++;
 	size_left = in_buff_cnt;
 	if ( size_left < NETFLOW_V9_HEADER_LENGTH ) {
+		syslog(LOG_ERR, "Process_v9: Too little data for v9 packets: '%lli'", (long long)size_left);
 		syslog(LOG_ERR, "Process_v9: Too little data for v9 packets: '%lli'", (long long)size_left);
 		return;
 	}
@@ -1542,7 +1569,7 @@ static int pkg_num = 0;
 		}
 
 #ifdef DEVEL
-		if ( (ptrdiff_t)fs->nffile.writeto & 0x3 ) {
+		if ( (ptrdiff_t)fs->nffile->writeto & 0x3 ) {
 			fprintf(stderr, "PANIC: alignment error!! \n");
 			exit(255);
 		}
@@ -2229,7 +2256,7 @@ time_t		now = time(NULL);
 
 #ifdef DEVEL
 //	char		*string;
-//	format_file_block_record(master_record, 1, &string, 0, 0);
+//	format_file_block_record(master_record, 1, &string, 0);
 //	dbg_printf("%s\n", string);
 #endif
 
