@@ -388,18 +388,9 @@ srecord_t	*commbuff;
 	fs = FlowSource;
 	while ( fs ) {
 
-		// Init block header
-		fs->nffile.block_header->NumRecords = 0;
-		fs->nffile.block_header->size 		= 0;
-		fs->nffile.block_header->id			= DATA_BLOCK_TYPE_2;
-		fs->nffile.block_header->pad		= 0;
-		fs->nffile.writeto 					= (void *)((pointer_addr_t)fs->nffile.block_header + sizeof(data_block_header_t) );
-		fs->nffile.file_blocks		 		= 0;
-		fs->nffile.compress		 			= compress;
-
 		// prepare file
-		fs->nffile.wfd = OpenNewFile(fs->current, &string, compress);
-		if ( string != NULL ) {
+		fs->nffile = OpenNewFile(fs->current, NULL, compress, 0, &string);
+		if ( !fs->nffile ) {
 			syslog(LOG_ERR, "%s", string);
 			return;
 		}
@@ -501,17 +492,17 @@ srecord_t	*commbuff;
 
 				if ( verbose ) {
 					// Dump to stdout
-					format_file_block_header(fs->nffile.block_header, &string, 0, 0);
+					format_file_block_header(fs->nffile->block_header, &string, 0);
 					printf("%s\n", string);
 				}
 
-				if ( fs->nffile.block_header->NumRecords ) {
+				if ( fs->nffile->block_header->NumRecords ) {
 					// flush current buffer to disc
-					if ( WriteBlock(&(fs->nffile)) <= 0 )
+					if ( WriteBlock(fs->nffile) <= 0 )
 						syslog(LOG_ERR, "Ident: %s, failed to write output buffer to disk: '%s'" , fs->Ident, strerror(errno));
 					else 
 						// update successful written blocks
-						fs->nffile.file_blocks++;
+						fs->nffile->file_header->NumBlocks++;
 				} // else - no new records in current block
 
 	
@@ -526,12 +517,12 @@ srecord_t	*commbuff;
 				fs->stat_record.msec_last	= fs->last_seen - fs->stat_record.last_seen*1000;
 	
 				// Write Stat record and close file
-				CloseUpdateFile(fs->nffile.wfd, &fs->stat_record, fs->nffile.file_blocks, fs->Ident, compress, &string );
+				CloseUpdateFile(fs->nffile, &fs->stat_record, fs->Ident, &string );
 				if ( string != NULL ) {
 					// closing the file failed. maybe disk full ??
 					syslog(LOG_ERR, "Ident: %s, %s", fs->Ident, string);
 				}
-	
+
 				if ( subdir && !SetupSubDir(fs->datadir, subdir, error, 255) ) {
 					// in this case the flows get lost! - the rename will fail
 					// but this should not happen anyway, unless i/o problems, inode problems etc.
@@ -564,32 +555,24 @@ srecord_t	*commbuff;
 					fs->Ident, (unsigned long long)fs->stat_record.numflows, (unsigned long long)fs->stat_record.numpackets, 
 					(unsigned long long)fs->stat_record.numbytes, fs->stat_record.sequence_failure, fs->bad_packets);
 
-				// Initialize block header and write pointer for next block
-				fs->nffile.block_header->NumRecords = 0;
-				fs->nffile.block_header->size 		= 0;
-				fs->nffile.writeto = (void *)((pointer_addr_t)fs->nffile.block_header + sizeof(data_block_header_t) );
-
 				// reset stat record
 				memset((void *)&fs->stat_record, 0, sizeof(stat_record_t));
 				fs->bad_packets = 0;
 				fs->first_seen 	= 0xffffffffffffLL;
 				fs->last_seen 	= 0;
-				fs->nffile.file_blocks	= 0;
+
+				if ( !done ) {
+					fs->nffile = OpenNewFile(fs->current, fs->nffile, compress, 0, &string);
+					if ( !fs->nffile ) {
+						syslog(LOG_ERR, "Fatal: ident: %s, %s", fs->Ident, string);
+						syslog(LOG_ERR, "Suicide due to fatal error!");
+						break;
+					}
+				}
 
 				// Dump all extension maps to the buffer
 				FlushExtensionMaps(fs);
 
-				if ( !done ) {
-					fs->nffile.wfd = OpenNewFile(fs->current, &string, compress);
-					if ( string != NULL ) {
-						syslog(LOG_ERR, "Ident: %s, %s", fs->Ident, string);
-						syslog(LOG_ERR, "New flows will get lost!\n");
-	
-						// do not crash or terminate
-						fs->nffile.wfd =  0;
-					}
-				}
-
 				// next flow source
 				fs = fs->next;
 			} // end of while (fs)
@@ -711,26 +694,14 @@ srecord_t	*commbuff;
 		export_packets++;
 
 		// flush current buffer to disc
-		if ( fs->nffile.block_header->size > BUFFSIZE ) {
+		if ( fs->nffile->block_header->size > BUFFSIZE ) {
 			// fishy! - we already wrote into someone elses memory! - I'm sorry
 			// reset output buffer - data may be lost, as we don not know, where it happen
-			fs->nffile.block_header->size 		= 0;
-			fs->nffile.block_header->NumRecords	= 0;
-			fs->nffile.writeto = (void *)((pointer_addr_t)fs->nffile.block_header + sizeof(data_block_header_t) );
+			fs->nffile->block_header->size 		 = 0;
+			fs->nffile->block_header->NumRecords = 0;
+			fs->nffile->writeto = (void *)((pointer_addr_t)fs->nffile->block_header + sizeof(data_block_header_t) );
 			syslog(LOG_ERR, "### Software bug ### Ident: %s, output buffer overflow: expect memory inconsitency", fs->Ident);
 		}
-/*
-		if ( fs->nffile.block_header->size > OUTPUT_FLUSH_LIMIT ) {
-			if ( WriteBlock(fs->nffile) <= 0 ) {
-				syslog(LOG_ERR, "Failed to write output buffer to disk: '%s'" , strerror(errno));
-			} else {
-				fs->nffile.block_header->size 		= 0;
-				fs->nffile.block_header->NumRecords	= 0;
-				fs->nffile.writeto = (void *)((pointer_addr_t)fs->nffile.block_header + sizeof(data_block_header_t) );
-				fs->nffile.file_blocks++;
-			}
-		}
-*/
 	}
 
 	if ( verbose && blast_failures ) {
@@ -740,7 +711,7 @@ srecord_t	*commbuff;
 
 	fs = FlowSource;
 	while ( fs ) {
-		free((void *)fs->nffile.block_header);
+		DisposeFile(fs->nffile);
 		fs = fs->next;
 	}
 
@@ -1145,13 +1116,6 @@ int		c;
 			exit(255);
 		}
 
-		// setup output memory buffer
-		fs->nffile.block_header = (data_block_header_t *)malloc(BUFFSIZE + sizeof(data_block_header_t));
-		if ( !fs->nffile.block_header ) {
-			syslog(LOG_ERR, "malloc() allocation error in %s line %d: %s\n", __FILE__, __LINE__, strerror(errno) );
-			exit(255);
-		}
-
 		fs = fs->next;
 	}
 
